Description Usage Arguments Value Examples
View source: R/read_clean_output.R
Removes the lines with NA in simulation and remove the corresponding
rows in (parameter).
1 | filter_na(simulation, parameter)
|
simulation |
A matrix of real numbers. |
parameter |
A matrix of real numbers with the same number of rows as
|
A list containing as first element filtered_simulation (i.e.
without rows with NA), as second element filtered_parameter (i.e.
without the rows with the same index as the ones removed from simulation)
and as third element the indexes of the rows of simulation with NA.
1 2 3 4 5 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.