Description Usage Arguments Value
View source: R/read_clean_output.R
Import simulations, removes simulations with NA and keep only given list of parameters.
1 | read_clean_output(file, keep_param = NULL, two_env = F, ...)
|
file |
Name of the simulation file to import. |
keep_param |
Vector of names corresponding to the names of parameters to keep for the inference. i.e. the parameters varying in the simulations. |
two_env |
Logical. TRUE if teh sumstat correspond to two environments and FALSE if it correspond to one. Default = FALSE. |
... |
Options which will be passed to |
A list. The first element is a matrix of the simulation raw results
(i.e. the fitness of the mutants). Each row correspond to one simulation. The
second element is a matrix of the parameters (only the ones named in keep_param).
Each row contains the parameters of the corresponding row of "simulation".
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.